<?php
/*
 * 异步通知的处理类
 */
class WC_Gateway_Alipay_Response 
{
    private $gateway = null;
    
    public function __construct($gateway) {
        $this->gateway = $gateway;
        add_action('woocommerce_api_wc_gateway_alipay', array($this, 'check_response'));
    }
    
    /*
     * 验证请求中的签名，确保请求是来自于支付宝
     */
    public function check_response() {
        
        // 如果没有任何数据，直接不再执行
        if ( empty($_POST) ) {
            echo 'fail';
            exit();
        }
        
        // 验证签名，失败的话，不再执行后续代码，并输出fail
        $aop = new AopClient();
        $aop->appId = $this->gateway->app_id;
        $aop->gatewayUrl = $this->gateway->is_sandbox ? 'https://openapi.alipaydev.com/gateway.do' : 'https://openapi.alipay.com/gateway.do';
        $aop->rsaPrivateKey = $this->gateway->rsa2_secret;
        $aop->signType = 'RSA2';
        $aop->alipayrsaPublicKey = $this->gateway->alipay_pubkey;
        
        // 调用支付宝sdk中验证签名方法
        $posted = wp_unslash($_POST);
        $result = $aop->rsaCheckV1($posted, $this->gateway->alipay_pubkey,'RSA2');
        if (!$result) {
            echo 'fail';
            exit();
        }
        
        $this->process_biz($posted);
        
    }
    
    /**
     * 签名验证完毕后需要处理的事情
     * 1、接受out_trade_no
     * 2、判断订单是否存在
     * 3、根据交易状态做不同事情
     */
    public function process_biz($posted) {
        // 判断订单号是否存在
        if ( empty($posted['out_trade_no']) ) {
            echo 'fail';
            exit();
        }
        // 判断订单是否存在
        $order = wc_get_order($posted['out_trade_no']);
        if (!$order) {
            echo 'fail';
            exit;
        }
        // 检查交易状态
        if ($posted['trade_status'] == 'TRADE_SUCCESS') {
            
            // 增加一条订单备注
            $date = isset($posted['gmt_create']) ? $posted['gmt_create'] : date('Y-m-d H:i:s');
            $msg = $date.' 顾客使用支付宝完成支付';
            $order->add_order_note($msg);
            
            // 更新订单状态、设置正确的库存
            $order->payment_complete();
            
            // 保存支付宝的交易号
            update_post_meta($order->get_id(), 'alipay_trade_no', $posted['trade_no']);
            
            echo 'success';
            exit(); 
        } else {
            echo 'fail';
            exit();
        }
    }
}

