<?php

class WC_Gateway_Alipay extends WC_Payment_Gateway {
    
    public function __construct() {
        // 必要的字段
        $this->id = 'wcc_alipay';
        $this->icon = WCC_ALIPAY_PLUGIN_URL.'assets/alipay.png';
        $this->has_fields = false;
        $this->method_title = '支付宝';
        $this->method_description = '支付宝网关设置';
        
        // 必须调用的方法
        $this->init_form_fields();
        $this->init_settings();
        
        // 设置request或者response对象会用到的变量
        $this->title            = $this->get_option('title');
        $this->description      = $this->get_option('description');
        $this->app_id           = $this->get_option('app_id');
        $this->rsa2_secret      = $this->get_option('rsa2_secret');
        $this->alipay_pubkey    = $this->get_option('alipay_pubkey');
        $this->is_sandbox       = 'yes'===$this->get_option('sandbox');
        
        
        // 保存后台设置的数据
        add_action( 'woocommerce_update_options_payment_gateways_' . $this->id, array( $this, 'process_admin_options' ) );
        
        // 实例化异步通知的处理
        new WC_Gateway_Alipay_Response($this);
        
    }
    
    /*
     * 处理支付宝付款
     * 生成完整的支付宝付款的Url
     * @param int $order_id 
     */
    public function process_payment($order_id) {
        
        $request = new WC_Gateway_Alipay_Request($this);
        $order = wc_get_order($order_id);
        
        $url = $request->get_return_url($order);
        
        return array(
            'result'    =>  'success',
            'redirect'  =>  $url
        );
    }
    
    public function init_form_fields() {
        $this->form_fields = array(
            'enabled' => array(
                    'title'   => "启用/禁用",
                    'type'    => 'checkbox',
                    'label'   => "是否启用支付宝网关，勾选为启用",
                    'default' => 'yes',
            ),
            'title' => array(
                    'title'       => "标题",
                    'type'        => 'text',
                    'description' => '在结算时看到的当前支付方式的名称',
                    'default'     => '支付宝',
                    'desc_tip'    => true,
            ),
            'description' => array(
                    'title'       => '描述',
                    'type'        => 'text',
                    'desc_tip'    => true,
                    'description' => '结算时当前支付方式的描述',
                    'default'     => '将使用支付宝付款',
            ),
            'app_id'    => array(
                    'title'       => 'APPID',
                    'type'        => 'text',
                    'desc_tip'    => true,
                    'description' => '支付宝给你提供的APPID',
                    'default'     => '',
            ),
            'rsa2_secret'  => array(
                    'title'       => 'RSA2私钥',
                    'type'        => 'text',
                    'desc_tip'    => true,
                    'description' => '你创建的商家私钥，和在支付宝开放平台设定的公钥对应的私钥',
                    'default'     => '',
            ),
            'alipay_pubkey' => array(
                    'title'       => '支付宝公钥',
                    'type'        => 'text',
                    'desc_tip'    => true,
                    'description' => '支付宝给你提供的公钥，不是商家的公钥',
                    'default'     => '',
            ),
            'sandbox'   => array(
                    'title'   => "启用/禁用沙箱模式",
                    'type'    => 'checkbox',
                    'label'   => "是否启用沙箱模式，勾选为启用",
                    'default' => 'no',
            )
        );
    }
    
    
}


